## order ##
## GenerateDotCorPlots (mapped genome)
## GenCircosKaryotypeHightlights 
## GenAllmaps 
setwd('~/Desktop/Old_Desktop/Map Paper/DATA/')
plotdir <- '~/Desktop/Old_Desktop/Map Paper/raw_figures'
x <- c('stringr','reshape2','gdata')
lapply(x, require, character.only = TRUE)

#### Generate tables and plots ####
##### Read lifted over GFF from ALLMAPS #####
gff <- read.delim('unsplit_ncbi.gff',header=F, comment.char="#")
gff <- gff[which(gff$V3=='gene'),]
gff <- data.frame(gff,NCBI_scaff=gsub('.*NOTES=','',gff$V9), stringsAsFactors = FALSE)
gff$V1 <- gsub('chr','',gff$V1)
gff$V9 <- gsub('.*Dbxref=GeneID:','', gff$V9)
gff$V9 <- gsub(';Name=.*','', gff$V9)
gff <- gff[!duplicated(gff$V9),]
row.names(gff) <- gff$V9
#######################################
##### Get one to one orthologs #####
fish12a.orthomcl.1to1n <- read.table("fish12a-orthomcl-1to1n.tab",
                                     header=TRUE, stringsAsFactors=FALSE, 
                                     sep = "\t") ##All kfish orthologs from evigene

row.names(fish12a.orthomcl.1to1n) <- fish12a.orthomcl.1to1n$OID

fish12.kfish2 <- read.table("fish12.kfish2.idtab",
                            header=FALSE, stringsAsFactors=FALSE, 
                            sep = "\t" ) ## Relates ensmbl gene with OID

fish12.kfish2 <- fish12.kfish2[!duplicated(fish12.kfish2$V2),]
fish12.kfish2$V2 <- gsub('euGenes:FISH12I_G','',fish12.kfish2$V2) ### Remove the species identifier from each gene
row.names(fish12.kfish2) <- as.character(gsub('t1','',fish12.kfish2$V1))
kfish.orthos <- fish12a.orthomcl.1to1n[fish12a.orthomcl.1to1n$kfish2==1,] ##only those that have 1 gene in kfish
##################################
##### Get the positions of gene models (Funhe names) on Scaffolds (kfish2) #####
kfish.genes <- read.table("kfish2genexml-results.csv",
                          header=TRUE, 
                          stringsAsFactors=FALSE, 
                          sep = ",") ### Gene ID, scaff/position, and additional info

kfish.genes <- data.frame(gene=kfish.genes[,1],
                          position=gsub('Scaffold','',kfish.genes[,2]), 
                          row.names=kfish.genes[,1])

kfish.genes <- kfish.genes[grep("NOPATH:1-69:.", kfish.genes[,2], invert=TRUE),] ##find those that do not have position = 2,267 genes
kfish.genes <- kfish.genes[grep(":./", kfish.genes[,2], invert=TRUE),] ### Take out the split genes = 2,138 genes
kfish.genes.info <- str_split_fixed(kfish.genes[,2], ':', 3)[,1:2] ##3 Split the position column into scaffold and position
kfish.genes <- data.frame(kfish.genes$gene,scaff=kfish.genes.info[,1],pos=str_split_fixed(kfish.genes.info[,2], '-', 2),check.rows=TRUE) ## New df with gene,scaff,position
kfish.genes$pos.1 <- as.numeric(as.character(kfish.genes$pos.1))
kfish.genes$pos.2 <- as.numeric(as.character(kfish.genes$pos.2))
row.names(kfish.genes) <- kfish.genes$kfish.genes.gene
print(paste(dim(kfish.genes)[1], 'killifish othologs used'))
##########################################################################
##### Convert gff to Funhe names for Ortho analysis #####
outliers.cnv <- read.table(file = 'gene_model_conversion_outliers.csv', 
                           header = TRUE, 
                           sep = ',') ## Relates ensembl gene id to NCBI gene id and NCBI scaff

outliers.cnv <- data.frame(outliers.cnv, 
                           scaff=kfish.genes[as.character(outliers.cnv$Killifish.geneID),2], 
                           stringsAsFactors = FALSE) ## Adds ensmbl scaff to convert to NCBI

AW.conv <- read.table('Scaffold_names_conversion_table.csv', 
                      stringsAsFactors = FALSE, 
                      header = TRUE, 
                      sep = ',') ## Adds corrected NCBI scaffold to outliers

cnvrt <- AW.conv$RefSeq.Accession.version
names(cnvrt) <- gsub('Scaffold','',AW.conv$corrected)

outliers.cnv <- data.frame(outliers.cnv, 
                           NCBI_scaff= cnvrt[as.character(outliers.cnv$scaff)], 
                           stringsAsFactors = FALSE) ## Adds corrected NCBI scaffold to outliers
## Remove genes that do not have an NCBI model
outliers.cnv <- outliers.cnv[which(outliers.cnv$NCBI_GeneID!=0),]
## Remove Funhe genes that have the same NCBI gene name
outliers.cnv <- outliers.cnv[!duplicated(outliers.cnv$NCBI_GeneID),]###converts NCBI_GeneID and Killifish_geneID
row.names(outliers.cnv) <- outliers.cnv$NCBI_GeneID 

outliers.cnv <- data.frame(outliers.cnv, 
                           chrm=gff[rownames(outliers.cnv),1],
                           stringsAsFactors = FALSE)

print(paste('using',length(outliers.cnv$Killifish.geneID),'NCBI genes'))

gff <- data.frame(gff, Funhe=outliers.cnv[as.character(gff$V9),1],stringsAsFactors = FALSE)
## Take only mapped orthologs
gff <- gff[!is.na(as.numeric(gff$V1)),]
#######################################################
##### Medaka #####
fish12.medaka <- read.table("fish12.medaka.idtab",header=FALSE, stringsAsFactors=FALSE, sep = "\t" ) ####Table of genes
fish12.medaka$V2 <- gsub('euGenes:FISH12I_G','',fish12.medaka$V2)
fish12.medaka <- fish12.medaka[!fish12.medaka$V2=='noid',] ## 18,166 genes with an orthoIDs (may not have kfish ortho)
fish12.medaka <- fish12.medaka[!duplicated(fish12.medaka$V2),] ##~5,000 genes have the same otho id
row.names(fish12.medaka) <- fish12.medaka$V1
kfish.medaka.orthos <- kfish.orthos[which(kfish.orthos$medaka==1),]  ## 7,519/8867 in common w/medaka

write.table(fish12.medaka$V1[fish12.medaka$V2 %in% kfish.medaka.orthos$OID], 
            file='ensmbl.medaka',
            row.names=FALSE, col.names=FALSE, sep="\r",quote=FALSE)##Use this table of genes to find chromsomal locations

## ensmbl file -> biomart 
medaka.genes <- read.table("mart_export_medaka.txt",header=TRUE, stringsAsFactors=FALSE, sep = "\t" )##Read back in
medaka.genes <- medaka.genes[!duplicated(medaka.genes$Ensembl.Protein.ID),] # remove split/duplicated genes
medaka.genes <- data.frame(medaka.genes,OID=fish12.medaka[medaka.genes$Ensembl.Protein.ID,2], stringsAsFactors = FALSE)
medaka.genes <- medaka.genes[!is.na(medaka.genes$OID),]
medaka.genes <- medaka.genes[!duplicated(medaka.genes$OID),]
row.names(medaka.genes) <- fish12.medaka[medaka.genes$Ensembl.Protein.ID,2]
medaka.genes$Chromosome.Name[is.na(as.numeric(medaka.genes$Chromosome.Name))] <- 0
################
##### Platyfish #####
## http://genome.uoregon.edu/xma/index_v1.0.php
fish12.platyfish <- read.table("fish12.platyfish.idtab",header=FALSE, stringsAsFactors=FALSE, sep = "\t" ) ####Table of genes
fish12.platyfish$V2 <- gsub('euGenes:FISH12I_G','',fish12.platyfish$V2)
fish12.platyfish <- fish12.platyfish[!fish12.platyfish$V2=='noid',] ##  genes with an orthoIDs (may not have kfish ortho)
fish12.platyfish <- fish12.platyfish[!duplicated(fish12.platyfish$V2),] ##~5,000 genes have the same otho id
row.names(fish12.platyfish) <- fish12.platyfish$V3
kfish.platyfish.orthos <- kfish.orthos[which(kfish.orthos$platyfish==1),]  ## 8561/8867 in common w/platy
### Rather than ensmbl, I got positions from the gtf
platyfish.genes <- read.table('Xiphophorus_maculatus.Xipmac4.4.2.76-translated.gtf', 
                              sep = "\t", header = FALSE, stringsAsFactors = FALSE)

platyfish.genes <- platyfish.genes[platyfish.genes$V3=='gene',]
platyfish.genes$V9 <- gsub('; gene_name.*' ,'',platyfish.genes$V9)
platyfish.genes$V9 <- gsub('; gene_source.*' ,'',platyfish.genes$V9)
platyfish.genes$V9 <- gsub('gene_id ' ,'',platyfish.genes$V9)
platyfish.genes$V1 <- gsub('LG' ,'',platyfish.genes$V1)
platyfish.genes <- platyfish.genes[!duplicated(platyfish.genes$V9),]

## Format the gtf similar to ensmbl output
platyfish.genes <- data.frame(gene=platyfish.genes$V9, 
                              Chromosome.Name=platyfish.genes$V1,
                              gene.start=platyfish.genes$V4, 
                              gene.stop=platyfish.genes$V5, 
                              OID=fish12.platyfish[as.character(platyfish.genes$V9),2],
                              stringsAsFactors = FALSE)

platyfish.genes <- platyfish.genes[!duplicated(platyfish.genes$OID),] ## No same OID
platyfish.genes <- platyfish.genes[!is.na(platyfish.genes$OID),]
row.names(platyfish.genes) <- platyfish.genes$OID
## fixed this to remove duplicate entries of OID
platyfish.genes <- platyfish.genes[which(platyfish.genes$OID %in% kfish.platyfish.orthos$OID),]
colnames(platyfish.genes)<- colnames(medaka.genes)
platyfish.genes <- platyfish.genes[!is.na(platyfish.genes$Chromosome.Name),]
platyfish.genes$Chromosome.Name[is.na(as.numeric(platyfish.genes$Chromosome.Name))] <- 0
###################
##### zebrafish #####
fish12.zebrafish <- read.table("fish12.zebrafish.idtab",header=FALSE, stringsAsFactors=FALSE, sep = "\t" ) ####Table of genes
fish12.zebrafish$V2 <- gsub('euGenes:FISH12I_G','',fish12.zebrafish$V2)
fish12.zebrafish <- fish12.zebrafish[!fish12.zebrafish$V2=='noid',] ## 24,459 genes with an orthoIDs (may not have kfish ortho)
fish12.zebrafish <- fish12.zebrafish[!duplicated(fish12.zebrafish$V2),] 
fish12.zebrafish <- fish12.zebrafish[!is.na(fish12.zebrafish$V3),] # 15,517
row.names(fish12.zebrafish) <- fish12.zebrafish$V3
kfish.zebrafish.orthos <- kfish.orthos[which(kfish.orthos$zebrafish==1),]  ## 8,104/8,867 in common w/zebrafish
write.table(fish12.zebrafish$V1[fish12.zebrafish$V2 %in% kfish.zebrafish.orthos$OID], file='ensmbl.zebrafish',row.names=FALSE, col.names=FALSE, sep="\r",quote=FALSE)##Use this table of genes to find chromsomal locations

zebrafish.genes <- read.table("mart_export_zebrafish.txt",header=TRUE, stringsAsFactors=FALSE, sep = "\t" )##Read back in 6,412
zebrafish.genes <- zebrafish.genes[!duplicated(zebrafish.genes$Ensembl.Gene.ID),] # remove split/duplicated genes 6,390
zebrafish.genes <- zebrafish.genes[zebrafish.genes$Ensembl.Gene.ID%in%row.names(fish12.zebrafish),] # 6,378
zebrafish.genes <- data.frame(zebrafish.genes,OID=fish12.zebrafish[as.character(zebrafish.genes$Ensembl.Gene.ID),2], stringsAsFactors = FALSE)
zebrafish.genes <- zebrafish.genes[!is.na(zebrafish.genes$OID),]
zebrafish.genes <- zebrafish.genes[!duplicated(zebrafish.genes$OID),]
row.names(zebrafish.genes) <- fish12.zebrafish[zebrafish.genes$Ensembl.Gene.ID,2]
####################
##### Stickleback #####
fish12.stickleback <- read.table("fish12.stickleback.idtab",header=FALSE, stringsAsFactors=FALSE, sep = "\t" ) ####Table of genes
fish12.stickleback$V2 <- gsub('euGenes:FISH12I_G','',fish12.stickleback$V2)
fish12.stickleback <- fish12.stickleback[!fish12.stickleback$V2=='noid',] ## 18,166 genes with an orthoIDs (may not have kfish ortho)
fish12.stickleback <- fish12.stickleback[!duplicated(fish12.stickleback$V2),]
row.names(fish12.stickleback) <- fish12.stickleback$V3
kfish.stickleback.orthos <- kfish.orthos[which(kfish.orthos$stickleback==1),]  ## 7,519/8867 in common w/stickleback
write.table(fish12.stickleback$V1[fish12.stickleback$V2 %in% kfish.stickleback.orthos$OID], file='ensmbl.stickleback',row.names=FALSE, col.names=FALSE, sep="\r",quote=FALSE)##Use this table of genes to find chromsomal locations
stickleback.genes <- read.table("mart_export_stickleback.txt",header=TRUE, stringsAsFactors=FALSE, sep = "\t" )##Read back in
stickleback.genes <- stickleback.genes[!duplicated(stickleback.genes$Ensembl.Gene.ID),] # remove split/duplicated genes
stickleback.genes <- stickleback.genes[stickleback.genes$Ensembl.Gene.ID%in%row.names(fish12.stickleback),] # 6,378
stickleback.genes <- data.frame(stickleback.genes,OID=fish12.stickleback[stickleback.genes$Ensembl.Gene.ID,2], stringsAsFactors = FALSE)
stickleback.genes <- stickleback.genes[!is.na(stickleback.genes$OID),]
stickleback.genes <- stickleback.genes[!duplicated(stickleback.genes$OID),]
row.names(stickleback.genes) <- fish12.stickleback[stickleback.genes$Ensembl.Gene.ID,2] ## return OID in V2

#Rename stickleback LGs# 
trans.LG <- c(as.numeric(as.roman(gsub('group','',unique(stickleback.genes$Chromosome.Name)))))
names(trans.LG) <- unique(stickleback.genes$Chromosome.Name)
trans.LG[is.na(trans.LG)] <- names(trans.LG)[is.na(trans.LG)]
stickleback.genes$Chromosome.Name <- trans.LG[as.character(stickleback.genes$Chromosome.Name)]
stickleback.genes$Chromosome.Name[is.na(as.numeric(stickleback.genes$Chromosome.Name))] <- 0
#####################
##### Tetroadon #####
fish12.tetraodon <- read.table("fish12.tetraodon.idtab",header=FALSE, stringsAsFactors=FALSE, sep = "\t" ) ####Table of genes
fish12.tetraodon$V2 <- gsub('euGenes:FISH12I_G','',fish12.tetraodon$V2)
fish12.tetraodon <- fish12.tetraodon[!fish12.tetraodon$V2=='noid',] ## 17,832 genes with an orthoIDs (may not have kfish ortho)
fish12.tetraodon <- fish12.tetraodon[!duplicated(fish12.tetraodon$V2),] 
fish12.tetraodon <- fish12.tetraodon[!is.na(fish12.tetraodon$V3),] # 13,482
row.names(fish12.tetraodon) <- fish12.tetraodon$V3
kfish.tetraodon.orthos <- kfish.orthos[which(kfish.orthos$tetraodon==1),]  ## 7,485/8,867 in common w/tetraodon
write.table(fish12.tetraodon$V1[fish12.tetraodon$V2 %in% kfish.tetraodon.orthos$OID], file='ensmbl.tetraodon',row.names=FALSE, col.names=FALSE, sep="\r",quote=FALSE)##Use this table of genes to find chromsomal locations
tetraodon.genes <- read.table("mart_export_tetraodon.txt",header=TRUE, stringsAsFactors=FALSE, sep = "\t" )##Read back, 20,562 returned (duplicates!)
tetraodon.genes <- tetraodon.genes[!duplicated(tetraodon.genes$Ensembl.Gene.ID),] # remove split/duplicated genes 
tetraodon.genes <- tetraodon.genes[tetraodon.genes$Ensembl.Gene.ID%in%row.names(fish12.tetraodon),] 
tetraodon.genes <- data.frame(tetraodon.genes,OID=fish12.tetraodon[tetraodon.genes$Ensembl.Gene.ID,2], stringsAsFactors = FALSE)
tetraodon.genes <- tetraodon.genes[!is.na(tetraodon.genes$OID),]
tetraodon.genes <- tetraodon.genes[!duplicated(tetraodon.genes$OID),]
row.names(tetraodon.genes) <- fish12.tetraodon[tetraodon.genes$Ensembl.Gene.ID,2] # 13,482
tetraodon.genes <- tetraodon.genes[as.character(row.names(kfish.tetraodon.orthos)),]
tetraodon.genes$Chromosome.Name <- gsub('_random','',tetraodon.genes$Chromosome.Name)
tetraodon.genes$Chromosome.Name[which(tetraodon.genes$Chromosome.Name=='Un')] <- 0
###################
##### spotgar #####
fish12.spotgar <- read.table("fish12.spotgar3.idtab",header=FALSE, stringsAsFactors=FALSE, sep = "\t" ) ####Table of genes
fish12.spotgar$V2 <- gsub('euGenes:FISH12I_G','',fish12.spotgar$V2)
fish12.spotgar <- fish12.spotgar[!fish12.spotgar$V2=='noid',] ## 18,166 genes with an orthoIDs (may not have kfish ortho)
fish12.spotgar <- fish12.spotgar[!duplicated(fish12.spotgar$V2),]
row.names(fish12.spotgar) <- fish12.spotgar$V1
kfish.spotgar.orthos <- kfish.orthos[which(kfish.orthos$spotgar==1),]  ## 
write.table(fish12.spotgar$V1[fish12.spotgar$V2 %in% kfish.spotgar.orthos$OID], file='/Users/jeffreymiller/Desktop/MAP_FIGURES/ensmbl.spotgar',row.names=FALSE, col.names=FALSE, sep="\r",quote=FALSE)##Use this table of genes to find chromsomal locations
spotgar.genes <- read.table("mart_export_spotgar.txt",header=TRUE, stringsAsFactors=FALSE, sep = "\t" )##Read back in
spotgar.genes <- spotgar.genes[!duplicated(spotgar.genes$Ensembl.Protein.ID),] # remove split/duplicated genes
spotgar.genes <- data.frame(spotgar.genes,OID=fish12.spotgar[spotgar.genes$Ensembl.Protein.ID,2], stringsAsFactors = FALSE)
spotgar.genes <- spotgar.genes[!is.na(spotgar.genes$OID),]
spotgar.genes <- spotgar.genes[!duplicated(spotgar.genes$OID),]
row.names(spotgar.genes) <- as.character(fish12.spotgar[spotgar.genes$Ensembl.Protein.ID,2])
spotgar.genes <- spotgar.genes[,c(4,1,2,3,5)]
trans.LG <- c(as.numeric(as.roman(gsub('LG','',unique(spotgar.genes$Chromosome.Name)))))
names(trans.LG) <- unique(spotgar.genes$Chromosome.Name)
trans.LG[is.na(trans.LG)] <- names(trans.LG)[is.na(trans.LG)]
spotgar.genes$Chromosome.Name <- trans.LG[as.character(spotgar.genes$Chromosome.Name)]
spotgar.genes$Chromosome.Name[is.na(as.numeric(spotgar.genes$Chromosome.Name))] <- 0
#################
##### human #####
fish12.human <- read.table("fish12.human.idtab",header=FALSE, stringsAsFactors=FALSE, sep = "\t" ) ####Table of all genes with ENS ID
fish12.human$V2 <- gsub('euGenes:FISH12I_G','',fish12.human$V2)
fish12.human$V1 <- gsub('UniRef50_','',fish12.human$V1)
human.genes.convert <- read.table('mart_export_human_genes.txt',header=TRUE, stringsAsFactors=FALSE, sep = "\t") 
human.genes.convert <- human.genes.convert[!duplicated(human.genes.convert$Ensembl.Gene.ID),]
human.genes.convert <- human.genes.convert[!duplicated(human.genes.convert$UniProt.SwissProt.Accession),]
human.genes.convert <- data.frame(human.genes.convert$Ensembl.Gene.ID, row.names = human.genes.convert$UniProt.SwissProt.Accession)
fish12.human$V1 <- human.genes.convert[fish12.human$V1,]
fish12.human <- fish12.human[!is.na(fish12.human$V1),]
kfish.human.orthos <- kfish.orthos[kfish.orthos$human==1,]
human.1to1 <- fish12.human[fish12.human$V2 %in% kfish.human.orthos$OID,1]
write.table(human.1to1, file='ensmbl.human',row.names=FALSE, col.names=FALSE, sep="\r",quote=FALSE)##Use this table of genes to find chromsomal locations
row.names(fish12.human) <- fish12.human$V1
kfish.human.orthos <- kfish.orthos[which(kfish.orthos$human==1),]  ## /8,867 in common w/human
write.table(fish12.human$V1[fish12.human$V2 %in% kfish.human.orthos$OID], file='ensmbl.human',row.names=FALSE, col.names=FALSE, sep="\r",quote=FALSE)##Use this table of genes to find chromsomal locations
human.genes <- read.table("mart_export_human.txt",header=TRUE, stringsAsFactors=FALSE, sep = "\t" )##Read back, 4,948 returned (duplicates!)
human.genes <- human.genes[!duplicated(human.genes$Ensembl.Gene.ID),] # remove split/duplicated genes 
human.genes <- human.genes[human.genes$Ensembl.Gene.ID%in%row.names(fish12.human),] 
human.genes <- data.frame(human.genes,OID=fish12.human[human.genes$Ensembl.Gene.ID,2], stringsAsFactors = FALSE)
human.genes <- human.genes[!is.na(human.genes$OID),]
human.genes <- human.genes[!duplicated(human.genes$OID),]
human.genes$Chromosome.Name[which(human.genes$Chromosome.Name=='X')] <- 23
row.names(human.genes) <- fish12.human[human.genes$Ensembl.Gene.ID,2] 
human.genes$Chromosome.Name[is.na(as.numeric(human.genes$Chromosome.Name))] <- 0
###############
##### Color consistency across all plots #####
## https://www.nceas.ucsb.edu/~frazier/RSpatialGuides/colorPaletteCheatsheet.pdf
cnvrt.scaf <- data.frame(out=gsub('Scaffold','',AW.conv$corrected),
                         row.names = AW.conv$RefSeq.Accession.version )
cnvrt.ncbi <- AW.conv$RefSeq.Accession.version
names(cnvrt.ncbi) <- gsub('Scaffold','',AW.conv$corrected)
colorbrew <- read.table('colors.brewer.conf', sep = ' ')
colorbrew <- colorbrew[grep(',',colorbrew$V3),]
colorbrew <- data.frame(circ.color=colorbrew$V1,colsplit(colorbrew$V3,',',names = c('r','g','b') ))
set.seed(666)
#colorbrew <- colorbrew[sample(row.names(colorbrew),length(unique(gff$NCBI_scaff)), replace = FALSE),]
#row.names(colorbrew) <- sample(unique(gff$NCBI_scaff),replace = FALSE)
############################################
##### Scaffold specific coloration for killi and platyfish ##### 
platy.scaff <- read.table('platy.scaff.txt',
                          stringsAsFactors = F,
                          sep = '\t', header = T)

row.names(platy.scaff) <- platy.scaff$Gene.stable.ID
## These colors should be taken out of the scaffold color assignments for platyfish
colorbrew.platy <- colorbrew[grep('^yl', colorbrew$circ.color, invert = TRUE),]
colorbrew.platy <- colorbrew.platy[grep('spectral', colorbrew.platy$circ.color,invert = TRUE),]
## Assign color to each scaffold
colorbrew.platy <- colorbrew.platy[sample(row.names(colorbrew.platy),length(unique(platy.scaff$Chromosome.scaffold.name)), replace = TRUE),]
row.names(colorbrew.platy) <- sample(unique(platy.scaff$Chromosome.scaffold.name),replace = FALSE)
## done with colorbrew.platy

## Assign colors to killifish scaffolds ##
colorbrew <- colorbrew[sample(row.names(colorbrew),length(unique(unique(bigfile$scaff))), replace = FALSE),]
row.names(colorbrew) <- sample(unique(bigfile$scaff),replace = FALSE)
#colorbrew <- colorbrew[sample(row.names(colorbrew),length(unique(c(gff$NCBI_scaff,cnvrt.ncbi[scaffolds.f.ro$scaff],cnvrt.ncbi[scaffolds.m$scaff]))),replace = TRUE),]
#row.names(colorbrew) <- sample(unique(c(gff$NCBI_scaff,cnvrt.ncbi[scaffolds.f.ro$scaff],cnvrt.ncbi[scaffolds.m$scaff])))
## Make a simple coversion for scaffold name to color id for circos
pal <- rgb(colorbrew$r,colorbrew$g,colorbrew$b,maxColorValue=255)
names(pal) <- row.names(colorbrew)
## col=pal['scaffolds'] 
##########################################################
#### Dot, cor and circos plots ####
all<- c("XM","OL","GA","TN","DR","LO","HS")
names(all) <- c("platyfish","medaka","stickleback","tetraodon","zebrafish","spotgar","human")
ch.counts <- data.frame(matrix(NA, nrow = 24, ncol = 7))
ch.cor <- data.frame(matrix(NA, nrow = 24, ncol = 7))
ch.trnspo <- data.frame(matrix(NA, nrow = 24, ncol = 7))
colnames(ch.counts) <- names(all)
colnames(ch.cor) <- names(all)
colnames(ch.trnspo) <- names(all)

## Make all plots for paper ##
for (i in 1:length(all)){
  fish <- get(paste(names(all[i]),'.genes', sep = ''))
  gff.fish <- data.frame(gff, 
                         fish[as.character(fish12.kfish2[as.character(gff$Funhe),2]),],
                         stringsAsFactors = FALSE)            
  
  gff.fish <- gff.fish[!is.na(gff.fish$Chromosome.Name),]
  gff.fish <- gff.fish[!is.na(as.numeric(gff.fish$Chromosome.Name)),]
  gff.fish <- gff.fish[!duplicated(gff.fish$OID),]
  
  #  gff.fish <- gff.fish[order(as.numeric(gff.fish$V1),as.numeric(gff.fish$V4)),]
  
  common.fish <- fish12a.orthomcl.1to1n[which(fish12a.orthomcl.1to1n$human==1&fish12a.orthomcl.1to1n$kfish2==1&fish12a.orthomcl.1to1n$medaka==1&fish12a.orthomcl.1to1n$platyfish==1&fish12a.orthomcl.1to1n$spotgar3==1&fish12a.orthomcl.1to1n$stickleback==1&fish12a.orthomcl.1to1n$tetraodon==1&fish12a.orthomcl.1to1n$zebrafish==1),1]
  common.fish <- gff.fish[gff.fish$OID%in%common.fish,]
  ch.counts[,i] <- sapply(1:24,function(x)length(unique(common.fish$Chromosome.Name[which(common.fish$V1==x)]))/length(common.fish$Chromosome.Name[which(common.fish$V1==x)]))
  # ch.counts[,i] <- sapply(1:24, function(x)length(unique(gff.fish$Chromosome.Name[which(gff.fish$V1==x)]))/length(gff.fish$Chromosome.Name[which(gff.fish$V1==x)]))
  # number of LGs that recieved transpo / divided by number of genes
  # do I need to multiply by the number of destination chromosomes?
  ch.trnspo[,i] <- sapply(1:24, function(x)length(gff.fish$Chromosome.Name[which(gff.fish$V1==x)]) - max(table(gff.fish$Chromosome.Name[which(gff.fish$V1==x)])))
  # of orthologs found for FHLG X - # of orthologs found on top homolog
  ### ch.counts used in 7_TranslocationRate.r
  
  ##### Generate circos file #####
  ### Writes output to circos file
  zep <- rep.int(NA,times = length(gff.fish$V1))
  
  for (v in 1:length(gff.fish$V1)){
    zep[v] <- round(((1-length(which(gff.fish$Chromosome.Name[which(gff.fish$V1==gff.fish$V1[v])]==gff.fish$Chromosome.Name[v]))/sum(table(gff.fish$Chromosome.Name[which(gff.fish$V1==gff.fish$V1[v])])))*100)-1)
  }
  
  write.table(data.frame(fh=paste('FH',gff.fish$V1,sep = ''),str=gff.fish$V4,stp=gff.fish$V5,fishchrm=paste(all[i],gff.fish$Chromosome.Name,sep = ''),fishstr=gff.fish$Gene.Start..bp.,fishstp=gff.fish$Gene.End..bp.,color=paste('color=chr',gff.fish$V1,paste(',z=',zep,sep = ''),sep = '')),file=paste('~/software/circos/current/',names(all[i]),'.txt',sep = ''), quote = FALSE, col.names = FALSE, row.names = FALSE)
  write.table(data.frame(fh=paste('FH',gff.fish$V1,sep = ''),str=gff.fish$V4,stp=gff.fish$V5,fishchrm=paste(all[i],gff.fish$Chromosome.Name,sep = ''),fishstr=gff.fish$Gene.Start..bp.,fishstp=gff.fish$Gene.End..bp.,color=paste('color=chr',gff.fish$Chromosome.Name,paste(',z=',zep,sep = ''),sep = '')),file=paste('~/software/circos/current/',names(all[i]),'taxa.txt',sep = ''), quote = FALSE, col.names = FALSE, row.names = FALSE)
  write.table(data.frame(fh=paste('FH',gff.fish$V1,sep = ''),str=gff.fish$V4,stp=gff.fish$V5,fishchrm=paste(all[i],gff.fish$Chromosome.Name,sep = ''),fishstr=gff.fish$Gene.Start..bp.,fishstp=gff.fish$Gene.End..bp.,color=paste('color=',colorbrew[as.character(gff.fish$NCBI_scaff),1],sep = '')),file=paste('~/software/circos/current/',names(all[i]),'SCAF.txt',sep = ''), quote = FALSE, col.names = FALSE, row.names = FALSE)
  
  ## Platyfish specific
  if (i==1){
    write.table(data.frame(fh=paste('FH',gff.fish$V1,sep = ''),str=gff.fish$V4,stp=gff.fish$V5,fishchrm=paste(all[i],gff.fish$Chromosome.Name,sep = ''),fishstr=gff.fish$Gene.Start..bp.,fishstp=gff.fish$Gene.End..bp.,color=paste('color=',colorbrew.platy[platy.scaff[as.character(gff.fish$Ensembl.Protein.ID),4],1],sep = '')),file=paste('~/software/circos/current/',names(all[i]),'SCAF.platycolor.txt',sep = ''), quote = FALSE, col.names = FALSE, row.names = FALSE)
  }
  
  ##############################
  
  ##### Whole Genome Corplots ####
  #gff.fish <- gff.fish[order(as.numeric(gff.fish$Chromosome.Name),as.numeric(gff.fish$Gene.Start..bp.)),]
  x1 <- order(as.numeric(gff.fish$V1),as.numeric(gff.fish$V4))
  y1 <- order(as.numeric(gff.fish$Chromosome.Name),as.numeric(gff.fish$Gene.Start..bp.))
  pdf(paste('corplot_',ylab = all[i],'.pdf',sep = ''))
  plot(x1,y1,pch=20,cex=.6, col=pal[gff.fish$NCBI_scaff],xlab = paste(names(all[i]),'LG',sep = ' '), ylab = 'killifish LG', yaxt='n',xaxt='n')
  axis(2,at = round(apply(cbind(cumsum(table(as.numeric(gff.fish$V1)[x1])),c(1,cumsum(table(as.numeric(gff.fish$V1)[x1]))[-24])),1,mean))[c(seq(from = 1, to =24, by= 2))], labels=names(round(apply(cbind(cumsum(table(as.numeric(gff.fish$V1)[x1])),c(1,cumsum(table(as.numeric(gff.fish$V1)[x1]))[-24])),1,mean))[c(seq(from = 1, to =24, by= 2))]),las=2)
  axis(1,at = round(apply(cbind(cumsum(table(as.numeric(gff.fish$Chromosome.Name)[y1])),c(1,cumsum(table(as.numeric(gff.fish$Chromosome.Name)[y1]))[-length(table(as.numeric(gff.fish$Chromosome.Name)[y1]))])),1,mean))[c(seq(from = 1, to =length(table(as.numeric(gff.fish$Chromosome.Name)[y1])), by= 2))], labels=names(table(as.numeric(gff.fish$Chromosome.Name)[y1]))[c(seq(from = 1, to =length(table(as.numeric(gff.fish$Chromosome.Name)[y1])), by= 2))],las=2)
  abline(v=cumsum(table(as.numeric(gff.fish$Chromosome.Name)[y1])[1:24]),col = rgb(0, 0, 0, max = 255, alpha = 100))
  abline(h=cumsum(table(as.numeric(gff.fish$V1)[x1])),col = rgb(0, 0, 0, max = 255, alpha = 100))
  #rect(c(0,cumsum(table(as.numeric(gff.fish$Chromosome.Name)[y1])))[seq(from=1,to=length(table(gff.fish$Chromosome.Name)),by=2)],0,cumsum(table(as.numeric(gff.fish$Chromosome.Name)[y1]))[seq(from=1,to=length(table(gff.fish$Chromosome.Name)),by=2)],4204  ,col = rgb(211, 211, 211, max = 255, alpha = 35))
  #rect(0,cumsum(table(as.numeric(gff.fish$V1)[x1]))[seq(from=2,to=length(table(gff.fish$V1)),by=2)],max(gff.fish$Gene.End..bp.),c(cumsum(table(as.numeric(gff.fish$V1)[x1]))[seq(from=1,to=length(table(gff.fish$V1)),by=2)],max(gff.fish$Gene.End..bp.)),col = rgb(211, 211, 211, max = 255, alpha = 35))
  dev.off()
  ###########################
  
  ##### Dotplot for each Killifish LG ####
  pdf(paste('dotplot_',ylab = all[i],'.pdf',sep = ''))
  par(mfrow=c(5,5),mar=c(0,0,0,0),oma=c(3,3,3,3))
  homol.chrm <- data.frame(hi=NA,med=NA,lo=NA)
  for (z in 1:25){
    each <- gff.fish[gff.fish$V1==z,]
    try(homol.chrm[z,1:3] <- names(sort(table(each$Chromosome.Name), decreasing = TRUE)[1:3]),silent = TRUE)
    if (z==1||z==6||z==11||z==16){
      plot(each$V4/1000,each$Chromosome.Name, ylim=c(0,max(as.numeric(gff.fish$Chromosome.Name),na.rm = TRUE)),xlim=c(0,round(max(gff.fish$V4)/1000)),pch=21,lwd=.1,cex=.75,bg=pal[each$NCBI_scaff],xaxt='n',las=1)
      axis(2,at=c(0:max(as.numeric(gff.fish$Chromosome.Name))),las=2,labels = FALSE)
      rect(-2000,  seq(from=1.5, to=max(as.numeric(gff.fish$Chromosome.Name)), by = 2),max(each$V4), seq(from=1.5, to=max(as.numeric(gff.fish$Chromosome.Name)), by = 2)+1   ,col = rgb(211, 211, 211, max = 255, alpha = 50), border = NA)
      rect(-2000,  -0.5,max(each$V4),0.5,col = rgb(255, 197, 197, max = 255, alpha = 50), border = NA)
       #text(c('10000','20000'),-1)
    } else if (z==25){
      plot(c(0,round(max(gff.fish$V4)/1000)), c(0,24),xlim=c(0,round(max(gff.fish$V4)/1000)),lwd=.1,pch=21,cex=0,col=pal[each$NCBI_scaff], yaxt='n',las=1,xaxt='n')
      text(20000,12,names(all[i]), cex = 2)
      text(20000,6,paste('n=',dim(gff.fish)[1],' genes',sep = ''), cex = 1)
      rect(-2000,  -0.5,max(each$V4),0.5,col = rgb(255, 197, 197, max = 255, alpha = 50), border = NA)
      rect(-2000,  seq(from=1.5, to=max(as.numeric(gff.fish$Chromosome.Name)), by = 2)   ,max(each$V4), seq(from=1.5, to=max(as.numeric(gff.fish$Chromosome.Name)), by = 2)+1   ,col = rgb(211, 211, 211, max = 255, alpha = 50), border = NA)
    } else if (z==21) {
      plot(each$V4/1000,each$Chromosome.Name, ylim=c(0,max(as.numeric(gff.fish$Chromosome.Name),na.rm = TRUE)) ,xlim=c(0,round(max(gff.fish$V4)/1000)),pch=21,lwd=.1,cex=.75,bg=pal[each$NCBI_scaff],las=1,xaxt='n')
      rect(-2000,  seq(from=1.5, to=max(as.numeric(gff.fish$Chromosome.Name)), by = 2)   ,max(each$V4), seq(from=1.5, to=max(as.numeric(gff.fish$Chromosome.Name)), by = 2)+1   ,col = rgb(211, 211, 211, max = 255, alpha = 50), border = NA)
      rect(-2000,  -0.5,max(each$V4),0.5,col = rgb(255, 197, 197, max = 255, alpha = 50), border = NA)
      axis(2,at=c(0:max(as.numeric(gff.fish$Chromosome.Name))),las=2,labels = FALSE)
      axis(1,at=c(10000,30000),labels = paste(c(10,30),'Mb',sep = ''))
    } else if (z==22||z==23||z==24) {
      plot(each$V4/1000,each$Chromosome.Name, ylim=c(0,max(as.numeric(gff.fish$Chromosome.Name),na.rm = TRUE)),xlim=c(0,round(max(gff.fish$V4)/1000)),pch=21,lwd=.1,cex=.75,bg=pal[each$NCBI_scaff],yaxt='n',las=1,xaxt='n')
      rect(-2000,seq(from=1.5, to=max(as.numeric(gff.fish$Chromosome.Name)), by = 2)   ,max(each$V4), seq(from=1.5, to=max(as.numeric(gff.fish$Chromosome.Name)), by = 2)+1   ,col = rgb(211, 211, 211, max = 255, alpha = 50), border = NA)
      rect(-2000,  -0.5,max(each$V4),0.5,col = rgb(255, 197, 197, max = 255, alpha = 50), border = NA)
      axis(1,at=c(10000,30000),labels = paste(c(10,30),'Mb',sep = ''))
    } else {
      plot(each$V4/1000,each$Chromosome.Name, ylim=c(0,max(as.numeric(gff.fish$Chromosome.Name),na.rm = TRUE)),xlim=c(0,round(max(gff.fish$V4)/1000)),pch=21,lwd=.1,cex=.75,bg=pal[each$NCBI_scaff],yaxt='n',xaxt='n',las=1)
      rect(-2000,  seq(from=1.5, to=max(as.numeric(gff.fish$Chromosome.Name)), by = 2)   ,max(each$V4), seq(from=1.5, to=max(as.numeric(gff.fish$Chromosome.Name)), by = 2)+1   ,col = rgb(211, 211, 211, max = 255, alpha = 50), border = NA)
      rect(-2000,  -0.5,max(each$V4),0.5,col = rgb(255, 197, 197, max = 255, alpha = 50), border = NA)
    }
    try(bla <- rev(paste(all[i],homol.chrm$hi,sep = '')), silent = TRUE)
    write.table(bla,eol =',',quote = FALSE, row.names = FALSE,col.names = FALSE, file = paste('try',all[i],sep = ''), sep = ",")
  } 
  dev.off()
  ######################################
  
  ##### Dotplot for each taxa LG #####
  pdf(paste('dotplot_REV',ylab = all[i],'.pdf',sep = ''))
  par(mfrow=c(5,5),mar=c(0,0,0,0),oma=c(3,3,3,3))
  for (X in c(1,1:max(as.numeric(gff.fish$Chromosome.Name))+1)){
      each <- gff.fish[gff.fish$Chromosome.Name==X,]
    if (X==1||X==6||X==11||X==16||X==26){
      plot(each$Gene.Start..bp./1000,each$V1,lwd=.1, ylim=c(0,max(as.numeric(gff.fish$V1),na.rm = TRUE)),xlim=c(0,round(max(as.numeric(gff.fish$Gene.Start..bp.[which(gff.fish$Chromosome.Name%in%c(1:24))]))/1000)),pch=21,cex=.75,col='black', bg=pal[each$NCBI_scaff],xaxt='n',las=1)
      axis(2,at=c(1:max(as.numeric(gff.fish$V1))),las=2,labels = FALSE)
      rect(-2000,  seq(from=1.5, to=max(as.numeric(gff.fish$V1)), by = 2),max(each$Gene.Start..bp.), seq(from=1.5, to=max(as.numeric(gff.fish$V1)), by = 2)+1   ,col = rgb(211, 211, 211, max = 255, alpha = 50), border = NA)
      #text(c('10000','20000'),-1)
    } else if (X==max(as.numeric(gff.fish$Chromosome.Name))+1){
      plot(c(0,round(max(gff.fish$Gene.Start..bp.)/1000)),lwd=.1, c(0,24),xlim=c(0,round(max(gff.fish$Gene.Start..bp.)/1000)),pch=21,cex=0,col='black', bg=pal[each$NCBI_scaff], yaxt='n',las=1,xaxt='n')
      text(round(max(gff.fish$Gene.Start..bp.)/1000)/2,12,names(all[i]), cex = 2)
      text(round(max(gff.fish$Gene.Start..bp.)/1000)/2,6,paste('n=',dim(fish)[1],' genes',sep = ''), cex = 1)
      rect(-2000,  seq(from=1.5, to=max(as.numeric(gff.fish$V1)), by = 2),max(each$Gene.Start..bp.), seq(from=1.5, to=max(as.numeric(gff.fish$V1)), by = 2)+1   ,col = rgb(211, 211, 211, max = 255, alpha = 50), border = NA)
    } else if (X==21||X==26) {
      plot(each$Gene.Start..bp./1000,each$V1, lwd=.1, ylim=c(0,max(as.numeric(gff.fish$V1),na.rm = TRUE)) ,xlim=c(0,round(max(gff.fish$Gene.Start..bp.[which(gff.fish$Chromosome.Name%in%c(1:24))])/1000)),pch=21,cex=.75,col='black', bg=pal[each$NCBI_scaff],las=1,xaxt='n')
      rect(-2000,  seq(from=1.5, to=max(as.numeric(gff.fish$V1)), by = 2),max(each$Gene.Start..bp.), seq(from=1.5, to=max(as.numeric(gff.fish$V1)), by = 2)+1   ,col = rgb(211, 211, 211, max = 255, alpha = 50), border = NA)
      axis(2,at=c(1:max(as.numeric(gff.fish$V1))),las=2,labels = FALSE)
      axis(1,at=c(seq(0,max(each$Gene.Start..bp.)/1000, by = 5000)),labels = paste(seq(0,max(each$Gene.Start..bp.)/1000, by = 5000)/1000,'Mb',sep = ''))
    } else if (X==22||X>22&&X<max(as.numeric(gff.fish$Chromosome.Name))+1||X==max(as.numeric(gff.fish$Chromosome.Name))) {
      #plot(each$Gene.Start..bp./1000,each$V1,lwd=.1, ylim=c(0,max(as.numeric(gff.fish$V1),na.rm = TRUE)),xlim=c(0,round(max(gff.fish$Gene.Start..bp.)/1000)),pch=21,cex=.75,col='black', bg=pal[each$NCBI_scaff],yaxt='n',las=1,xaxt='n')
      plot(c(0,max(gff.fish$Gene.Start..bp./1000)),c(0,max(each$V1)), yaxt='n',las=1,xaxt='n', cex=0,ylim=c(0,max(as.numeric(gff.fish$V1),na.rm = TRUE)) ,xlim=c(0,round(max(gff.fish$Gene.Start..bp.[which(gff.fish$Chromosome.Name%in%c(1:24))])/1000)))
      points(each$Gene.Start..bp./1000,each$V1,lwd=.1,pch=21,cex=.75,col='black', bg=pal[each$NCBI_scaff]  )
      rect(-2000,  seq(from=1.5, to=max(as.numeric(gff.fish$V1)), by = 2),max(each$Gene.Start..bp.), seq(from=1.5, to=max(as.numeric(gff.fish$V1)), by = 2)+1   ,col = rgb(211, 211, 211, max = 255, alpha = 50), border = NA)
      axis(1,at=c(seq(0,max(each$Gene.Start..bp.)/1000, by = 5000)),labels = paste(seq(0,max(each$Gene.Start..bp.)/1000, by = 5000)/1000,'Mb',sep = ''))
    } else {
      plot(each$Gene.Start..bp./1000,each$V1,lwd=.1, ylim=c(0,max(as.numeric(gff.fish$V1),na.rm = TRUE)),xlim=c(0,round(max(gff.fish$Gene.Start..bp.[which(gff.fish$Chromosome.Name%in%c(1:24))])/1000)),pch=21,cex=.75,col='black', bg=pal[each$NCBI_scaff],yaxt='n',xaxt='n',las=1)
      rect(-2000,  seq(from=1.5, to=max(as.numeric(gff.fish$V1)), by = 2),max(each$Gene.Start..bp.), seq(from=1.5, to=max(as.numeric(gff.fish$V1)), by = 2)+1   ,col = rgb(211, 211, 211, max = 255, alpha = 50), border = NA)
    }
  } 
  dev.off()
  #################################
  
  ##### Corpolts for each FK LG ####
  pdf(paste('corplot_whole',ylab = all[i],'.pdf',sep = ''))
  par(mfrow=c(5,5),mar=c(0,0,0,0),oma=c(3,3,3,3))
  for (z in 1:24){
    each <- gff.fish[gff.fish$V1==z,]
    each <- each[which(each$Chromosome.Name==names(which.max(table(each$Chromosome.Name)))),]
    ch.cor[z,names(all[i])]<- abs(cor(apply(cbind(each$V4,each$V5),1,mean),apply(cbind(each$Gene.Start..bp.,each$Gene.End..bp.),1,mean)))
    x1 <- order(as.numeric(each$V1),as.numeric(each$V4))
    y1 <- order(as.numeric(each$Chromosome.Name),as.numeric(each$Gene.Start..bp.))
    if (z==1||z==6||z==11||z==16){
      plot(x1,y1,pch=21,cex=.75,lwd=.1,col='black', bg=pal[each$NCBI_scaff],xlab = paste(names(all[i]),'LG',sep = ' '), ylab = 'killifish LG',xaxt='n',las=1,yaxt='n')
    } else if (z==25){
      plot(x1,y1,pch=21,cex=.75,lwd=.1, cex=0,col=pal[each$NCBI_scaff],xlab = paste(names(all[i]),'LG',sep = ' '), ylab = 'killifish LG',xaxt='n',las=1,yaxt='n')
    } else if (z==21) {
      plot(x1,y1,pch=21,cex=.75,lwd=.1, col='black', bg=pal[each$NCBI_scaff],xlab = paste(names(all[i]),'LG',sep = ' '), ylab = 'killifish LG',xaxt='n',las=1,yaxt='n')
    } else if (z==22||z==23||z==24) {
      plot(x1,y1,pch=21,cex=.75,lwd=.1, col='black', bg=pal[each$NCBI_scaff],xlab = paste(names(all[i]),'LG',sep = ' '), ylab = 'killifish LG',xaxt='n',las=1,yaxt='n')
    } else {
      plot(x1,y1,pch=21,cex=.75,lwd=.1, col='black', bg=pal[each$NCBI_scaff],xlab = paste(names(all[i]),'LG',sep = ' '), ylab = 'killifish LG',xaxt='n',las=1,yaxt='n')
      
    }
    
  } 
  dev.off()
  #print (paste(names(all[i]),"done, Press [enter] to continue"))
  #number <- scan(n=1)
  #############################
}
##################################
###########END#############################

##### Analysis for number of singletons #####
getmode <- function(v) {
  uniqv <- unique(v)
  uniqv[which.max(tabulate(match(v, uniqv)))]
} ## Get mode for homolog designation
all.sing <- list() ## List of OID of singletons
### Populate list 
for (i in 1:5){
  fish <- get(paste(names(all[i]),'.genes', sep = ''))
  gff.fish <- data.frame(gff, 
                         fish[as.character(fish12.kfish2[as.character(gff$Funhe),2]),],
                         stringsAsFactors = FALSE)            
  ## leaves 
  gff.fish <- gff.fish[!is.na(gff.fish$Chromosome.Name),]
  gff.fish <- gff.fish[!is.na(as.numeric(gff.fish$Chromosome.Name)),]
  gff.fish <- gff.fish[!duplicated(gff.fish$OID),]
  gff.fish.pf <- gff.fish


### Platyfish scaffold orientation

  cor.pf <- sapply(c(1:24),function(X){
            fh <- which(gff.fish.pf$V1==X)
            tab.pf <- names(which.max(table(gff.fish.pf$Chromosome.Name[fh]))) 
            pf <- which(gff.fish.pf$V1==X & gff.fish.pf$Chromosome.Name==tab.pf)
            cor(gff.fish.pf$V4[pf],gff.fish$Gene.Start..bp.[pf])
            } 
          )
  names(cor.pf) <- c(1:24)

  hom.pf <- sapply(c(1:24),function(X){
          getmode(gff.fish.pf$Chromosome.Name[which(gff.fish.pf$V1==X)])
            }
          )
  names(hom.pf) <- names(cor.pf)

## Determine number of transpositions in all fish

  tp <- sapply(c(1:24),function(X){
    chrom <- gff.fish.pf$Chromosome.Name[which(gff.fish.pf$V1==X)]
    numo <- sum(!chrom %in% c(hom.pf[as.character(X)],'0'))
    numc <- sum(!names(table(chrom)) %in% c(hom.pf[as.character(X)],'0'))
    nums <- sum(table(chrom[!chrom %in% c(hom.pf[as.character(X)],'0')])==1)
    cbind(numo,numc,nums)
  })
  
  list.single <- list()
  list.single[[X]] <- sapply(c(1:24),function(X){
  chrom <- gff.fish.pf$Chromosome.Name[which(gff.fish.pf$V1==X)]
  C <- table(chrom[!chrom %in% c(hom.pf[as.character(X)],'0')])
  
  sapply(names(which(C==1)),function(O){
    gff.fish.pf$OID[which(gff.fish.pf$V1==X & gff.fish.pf$Chromosome.Name==O)]
    })
})
  table(unlist(list.single))  

  all.sing[[i]] <- unlist(list.single)  
  


  A <- sapply(1:24,function(X){
  chrom <- gff.fish.pf$Chromosome.Name[which(gff.fish.pf$V1==X)]
  table(chrom[!chrom %in% c(hom.pf[as.character(X)],'0')])
})
  #barplot(table(unlist(A)), main = names(all[i]) )
  ##
  if (names(all[i])=="tetraodon" ){
    tp <- tp[,-c(1,12,4,20,9,18)]
  } else if (names(all[i])=="stickleback") {
    tp <- tp[,-c(4,13,17,23,18,21)]
  }
  print(paste(sum(tp[1,]),'total transpositions with', 
            sum(tp[3,]),'singletons',
            sum(tp[3,])/sum(tp[1,]),'%',
            'of', length(gff.fish.pf$V1),
            'orthologs',
            sum(tp[3,])/ncol(tp), 'singletons per chromosome',
            sum(tp[3,])/length(gff.fish.pf$V1), '% are single ortholog transloc'
            )
      )
      

  print(names(all[i]))
  
}
hist(table(unlist(all.sing)), main = names(all[i]), breaks = c(1,2,3,4,5))
table(table(unlist(all.sing)))

###########END#############################

#### Analysis for scaffold size and orientation. #### 
##### Medaka #####
## For each scaffold in platy, determine if orthologs are pos or neg oriented to KF
## CORRELATE EACH PLATY TO KF ORTHOLOG
oz.gff <- read.table('ref_ASM31367v1_scaffolds.gff3',sep = '\t',header = FALSE, stringsAsFactors = FALSE)
  #scaf size
oz.agp <- tapply(oz.gff$V4,oz.gff$V1,max)
oz.gff <- oz.gff[oz.gff$V3=='gene',]
oz.gff$V9 <- gsub('.*Dbxref=GeneID:' ,'',oz.gff$V9)
oz.gff$V9 <- gsub(';gbkey.*' ,'',oz.gff$V9)
oz.gff$V9 <- gsub(';description.*' ,'',oz.gff$V9)
oz.gff <- oz.gff[!duplicated(oz.gff$V9),]
rownames(oz.gff) <- oz.gff$V9 
write.table(oz.gff$V9,file = 'oz.ensmbl',quote = F,row.names = F, col.names = F)
  
## converted from NCBI gene id to ensmb prot id
oz.ens <- read.table('mart_export_medakaSCAF.txt', sep = '\t',stringsAsFactors = F, header = T)
oz.ens <- data.frame(oz.ens,OID=fish12.medaka[oz.ens$Protein.stable.ID,2], stringsAsFactors = FALSE)
oz.ens <- oz.ens[!is.na(oz.ens$OID),]
oz.ens <- oz.ens[!duplicated(oz.ens$OID),]
row.names(oz.ens) <- fish12.medaka[oz.ens$Protein.stable.ID,2]
oz.ens$scaffold.Name <- oz.gff[as.character(oz.ens$NCBI.gene.ID),1]
  
fhpos <- gff.fish$V4[!is.na(gff.fish$Ensembl.Protein.ID)]  
names(fhpos) <- gff.fish$Ensembl.Protein.ID[!is.na(gff.fish$Ensembl.Protein.ID)]

  
cors.o <- sapply(unique(oz.ens$scaffold.Name),function(X){
  ozpos <- oz.ens[which(oz.ens$scaffold.Name==X),2]
  kfpos <- fhpos[as.character(oz.ens[which(oz.ens$scaffold.Name==X),4])]   
    if (length(pfpos)>1){
      cor(kfpos,ozpos)
    } else {
      return(NA)
    }
    
  } 
)  
  
p1 <- hist(oz.agp[names(which(cors.o>0))],breaks =10)
p2 <- hist(oz.agp[names(which(cors.o<0))],breaks =10)
  
plot(p1,col=rgb(0,0,1,1/4))
plot(p2,col=rgb(1,0,0,1/4), add=T)
  
plot(pf.agp[names(which(cors>0))],col=rgb(0,0,1,1/4))
############
##### Platyfish #####
## scaf length
pf.agp <- read.table('xma_washu_4.4.2-jhp_1.0.agp',sep = '\t')
pf.agp <- tapply(pf.agp$V3,pf.agp$V1,max)

## killifish position
gff.fish.pf <- data.frame(gff.fish.pf,
                          scaffold=platy.scaff[gff.fish.pf$Ensembl.Protein.ID,])

#fhpos <- gff.fish.pf$V4[!is.na(gff.fish.pf$Ensembl.Protein.ID)]  
#names(fhpos) <- gff.fish.pf$Ensembl.Protein.ID[!is.na(gff.fish.pf$Ensembl.Protein.ID)]
## only use those scaffolds that are on homologous chromosomes

cors <- sapply(unique(platy.scaff$Chromosome.scaffold.name),
          function(X){
          ## Platyfish position
          pfscaf.index <- which(gff.fish.pf$scaffold.Chromosome.scaffold.name==X)
          scaf.hom <- hom.kf[as.character(getmode(gff.fish.pf$Chromosome.Name[pfscaf.index]))]                       
          pfscaf.index <- pfscaf.index[which(pfscaf.index %in% which(gff.fish.pf$V1==scaf.hom))]
      
          if (length(pfscaf.index)>1){
          scafcor <- cor(gff.fish.pf$V4[pfscaf.index],
                      gff.fish.pf$Gene.Start..bp.[pfscaf.index])
          } else {
           return(NA)
          }
          if (cor.pf[scaf.hom]<0){ ## Switch the sign if the pf chromosome is flipped
            scafcor <- abs(scafcor)
          }
          return(scafcor)
       }
)
  
 
p1 <- hist(pf.agp[names(which(cors>0))],
           breaks =seq(0,8e+06,8e+6/10),
           xlim = range(0,8e+06))

p2 <- hist(pf.agp[names(which(cors<0))],
           breaks =seq(0,8e+06,8e+6/10),
           xlim = range(0,8e+06))

plot(p1,col=rgb(0,0,1,1/4))
plot(p2,col=rgb(1,0,0,1/4), add=T)

plot(sort(pf.agp[names(which(cors>0))]),col=rgb(0,0,1,1/4))
plot(sort(pf.agp[names(which(cors<0))]),col=rgb(1,0,0,1/4), add=T)

### only hi correlating chromosomes
hi <- unique(gff.fish.pf$scaffold.Chromosome.scaffold.name[gff.fish.pf$V1 %in% names(which(abs(cor.pf) > 0.8))])

p1 <- hist(pf.agp[names(which(cors>0))],
           breaks =seq(0,8e+06,8e+6/10),
           xlim = range(0,8e+06))

p2 <- hist(pf.agp[names(which(cors<0))],
           breaks =seq(0,8e+06,8e+6/10),
           xlim = range(0,8e+06))

plot(p1,col=rgb(0,0,1,1/4))
plot(p2,col=rgb(1,0,0,1/4), add=T)
###############
###########END#############################



